# Fluxwallet

A heavily modified bitcoinlib fork for use with Flux

https://github.com/1200wd/bitcoinlib

See companion project [lucidwallet](https://github.com/MorningLightMountain713/lucidwallet) for details on how to use

## UNDER DEVELOPMENT

## Features

* Full async support including db (via threads with aiosqlite)
* More transaction types
* Uses new SQLAlchemy 2.0
* Many speed optomisations
